====================
 URI Builder Module
====================

.. autoclass:: rfc3986.builder.URIBuilder

.. automethod:: rfc3986.builder.URIBuilder.add_scheme

.. automethod:: rfc3986.builder.URIBuilder.add_credentials

.. automethod:: rfc3986.builder.URIBuilder.add_host

.. automethod:: rfc3986.builder.URIBuilder.add_port

.. automethod:: rfc3986.builder.URIBuilder.add_path

.. automethod:: rfc3986.builder.URIBuilder.add_query_from

.. automethod:: rfc3986.builder.URIBuilder.add_query

.. automethod:: rfc3986.builder.URIBuilder.add_fragment

.. automethod:: rfc3986.builder.URIBuilder.finalize
